BLAST alignment, performed with local database, may not contain subject GI information. Also subject accession may contain version suffix.
This can make it difficult to analyze the results further. This function adds subject GI and removes subject accession version suffix.
To add GI GenInfo Identifiers table with them linked to accession numbers must be provided as data frame or SQLite database table.
add.gi.df must be a data frame with column one - accession numbers, column two - GenInfo Identifier numbers.
If add.gi = "DF" temporal SQLite database is created.
SQLite database table with accession and GI numbers should not contain duplicated rows.
It is also highly recommended to index accession numbers' variable in database.
delete.version executes in the first step, so if you use this option accession numbers
in add.gi table must not contain version suffix.
AcNum.column.name, GI.column.name, add.gi.ac.column.name and dd.gi.gi.column.name
must be column names exactly as in data frame.