A dataset containing target nucleotide sequences of Chlamydia pneumoniae that were downloaded from NCBI Nucleotide database (November, 2021). Target sequences are chosen from all available sequences as targets for discriminating probes.
meta.targetA data frame with 183 rows and 21 variables:
sequence identification number
sequence identification number
sequence identification number
date of note's creation
date of last note's update
database
organism name
sequence title
strain
taxon identificator
sequence length
biomolecule
molecular type
genome type
sequence completness
type of genetic and codon codes
strand
host
country
isolation material
collection date