character; vector of data frame column names with numeric variables that should be tested for conditions
trim.action
character; vector of test conditions; possible values are:
"more", "eqmore" (more or equal), "less", "eqless" (less or equal).
trim.thresh
numeric; vector of condition threshold values
Value
data frame without rows with values that do not satisfy the specified conditions.
Details
This function takes the vector of data frame variables and for each of them test if they satisfy the specified conditions.
Not satisfying values are deleted with the entire data frame row. You may set as many conditions for as many variables as you like.
trim.values must be exact column names as in data frame.